; RqdFlds.SC

;  This script contains the procs used for the validation rules on each table.
; A separate procedure is used for each table.

;  ****************************************
;  * FldBlank Procedure                   *
;  ****************************************
;
;  Procedure to test if the field passed as a parameter is blank. If the field
; is blank the procedure returns True, otherwise False is returned.

PROC FldBlank(fldnm,fldtxt)
 PRIVATE fldblnk

; fldnm   - Field name as defined in the table
; fldtxt  - Text to be inserted into the global variable "msg" that is displayed
;           to the user if the field is blank
; fldblnk - Variable for the logical result of the ISBLANK function

  EXECUTE "fldblnk = ISBLANK(["+fldnm+"])"    ;  Create a PAL statement to test
  IF fldblnk THEN                             ; if the field is blank. If it is
    MOVETO FIELD fldnm                        ; empty, move to the field, set
    msg = fldtxt+" must be entered"           ; the msg variable and return
    RETURN True
  ELSE
    RETURN False
  ENDIF
ENDPROC

WRITELIB "Intgrty" FldBlank
RELEASE PROCS FldBlank


;  ****************************************
;  * RqdRulesEmp Procedure                *
;  ****************************************
;
;   Employee Table procedure that checks for the required fields, inserts
;  default values if the field is left blank, and makes necessary comparison
;  between fields in the table for valid entries.  Tests are performed
;  sequentially.  At the first failure, the procedure returns False.  A True
;  is returned if all tests are passed.  The order of the required fields is
;  based on the order they appear on the form.

PROC RqdRulesEmp()
  IF FldBlank("Last Name","Last Name") THEN          ; Required Last Name
    RETURN False
  ENDIF
  IF FldBlank("First Name","First Name") THEN        ; Required First Name
    RETURN False
  ENDIF
  IF FldBlank("SSN","SSN") THEN                      ; Required SSN
    RETURN False
  ENDIF
  IF FldBlank("Birth Date","Birth Date") THEN        ; Required Birth Date
    RETURN False
  ENDIF
  IF FldBlank("Department","Department") THEN        ; Required Department
    RETURN False
  ENDIF
  IF FldBlank("Job Code","Job Code") THEN            ; Required Job Code
    RETURN False
  ENDIF
  IF FldBlank("Salary","Salary") THEN                ; Required Salary
    RETURN False
  ENDIF
  IF FldBlank("Work Phone","Work Phone") THEN        ; Required Home Phone
    RETURN False
  ENDIF
  IF ISBLANK([Date Hired]) THEN                      ; Default Hire Date
    [Date Hired] = TODAY()
  ENDIF
  IF ISBLANK([Exemptions]) THEN                      ; Default Exemptions
    [Exemptions] = 0
  ENDIF
  IF [Date Hired] < [Birth Date] + (16 * 365) THEN   ;  Check if Date Hired is
                                                     ; 16 years after Birth Date
    msg = "Birth Date and Hire Date must be 16 years apart"
    MOVETO [Date Hired]
    RETURN False
  ENDIF
  RETURN True
ENDPROC

WRITELIB "Intgrty" RqdRulesEmp
RELEASE PROCS RqdRulesEmp


;  ****************************************
;  * RqdRulesBenefits Procedure           *
;  ****************************************
;
;   Benefits Table procedure that inserts default values if the field is left
;  blank.  Since each field has a default, there are no required fields.

PROC RqdRulesBenefits()
  IF ISBLANK([Insurance Type]) THEN                  ; Default Insurance Type
    [Insurance Type] = "Aetna"
  ENDIF
  IF ISBLANK([Life Insurance]) THEN                  ; Default Life Insurance
    [Life Insurance] = 0
  ENDIF
  IF ISBLANK([Short Term Disab]) THEN                ; Default Short Term Disab
    [Short Term Disab] = "N"
  ENDIF
  IF ISBLANK([Long Term Disab]) THEN                 ; Default Long Term Disab
    [Long Term Disab] = "N"
  ENDIF
  IF ISBLANK([US Saving Bond]) THEN                  ; Default US Saving Bond
    [US Saving Bond] = 0
  ENDIF
  RETURN True
ENDPROC

WRITELIB "Intgrty" RqdRulesBenefits
RELEASE PROCS RqdRulesBenefits


;  ****************************************
;  * RqdRulesDepndnts Procedure           *
;  ****************************************
;
;   Benefits Table procedure that checks for the required fields.  Tests are
;  performed sequentially.  At the first failure, the procedure returns False.
;  A True is returned if all tests are passed.  The order of the required
;  fields is based on the order they appear on the form.


PROC RqdRulesDepndnts()
  IF FldBlank("Dependents SSN","Dependents SSN") THEN; Required Dependents SSN
    RETURN False
  ENDIF
  IF FldBlank("Last Name","Last Name") THEN          ; Required Last Name
    RETURN False
  ENDIF
  IF FldBlank("First Name","First Name") THEN        ; Required First Name
    RETURN False
  ENDIF
  RETURN True
ENDPROC

WRITELIB "Intgrty" RqdRulesDepndnts
RELEASE PROCS RqdRulesDepndnts
