;ErrPrnt.sc

PROC ErrorPrint()
 PRIVATE errorproc, cntr, smode
;
; Private variables:
;  errorproc  -  this is a private variable to prevent infinite loop if there
;                is an error in this procedure
;  cntr       -  counter variable to determine the file extension for the
;                error log file
;  smode      -  contains the result of SYSMODE so multiple calls to the
;                function do not have to be made
;
  CANVAS ON
  MESSAGE "Printing error log file, Please wait!"
  CANVAS OFF
  IF DRIVESPACE(SUBSTR(DIRECTORY(),1,1)) < 3000 THEN
    CANVAS ON
    BEEP SLEEP 100 BEEP SLEEP 100 BEEP
    MESSAGE "Not enough disk space to write error log, process cancelled!"
    SLEEP 4000
  ENDIF
  cntr = 1
  filenam = PRIVDIR() + "ERRLOG.001"        ;  Find the name of last log file
  WHILE ISFILE(filenam)                     ;  Find the name of last log file
    cntr = cntr + 1                         ; printed
    filenam = PRIVDIR() + "ERRLOG." +
              SUBSTR(FORMAT("w4,ez",cntr),2,3)
  ENDWHILE

  PRINT FILE filenam "Error log file: ",filenam,"\n\n"
  PRINT FILE filenam "Current Date:     ",TODAY(),"\n"
  PRINT FILE filenam "Current Time:     ",TIME(),"\n"
  PRINT FILE filenam "Error Code:       ",ERRORCODE(),"\n"
  PRINT FILE filenam "Error Message:    ",ERRORMESSAGE(),"\n"
  PRINT FILE filenam "Error User:       ",ERRORUSER(),"\n"
  PRINT FILE filenam "Central Memory:   ",MEMLEFT(),"\n"
  PRINT FILE filenam "Code Pool Memory: ",RMEMLEFT(),"\n"
  PRINT FILE filenam "Menu Choice:      ",MENUCHOICE(),"\n"
  IF MENUCHOICE() <> "Error" THEN             ;  If cursor is at a menu need to
    MENU ESC                                  ; cancel the menu selection
  ENDIF
  PRINT FILE filenam "Monitor Type:     ",MONITOR(),"\n"
  PRINT FILE filenam "Network Type:     ",NETTYPE(),"\n"
  PRINT FILE filenam "System Mode:      ",SYSMODE(),"\n"
  smode = SYSMODE()
  ;
  ;  If the process is in modes other than in a table on the workspace
  ; certain workspace informational functions either cause a script
  ; error or the return erroneous information.  Therefore, the current
  ; mode needs to be Main, Edit, CoEdit, or DataEntry.  If it is not
  ; one of these modes then the current mode is cancelled.  Some modes
  ; require the {Cancel} {Yes} options.  These are cancelled using
  ; CANCELEDIT.  The other modes only need {Cancel}, there is no Yes/No
  ; menu option.
  ;
  ; NOTE:  If the current table is in form view, returning from Create,
  ;        Graph, Password, Restructure, and Sort puts the table in
  ;        Table View so the functions below testing for type of
  ;        form will not be a true indicator of the workspace status.
  ;
  IF smode = "Create" OR smode = "Restructure" OR smode = "Sort" THEN
    MENU {Cancel}
  ENDIF
  IF smode = "Form" OR smode = "Report" OR smode = "Password" OR
     smode = "Graph" THEN
       CANCELEDIT
  ENDIF
  PRINT FILE filenam "Directory:        ",DIRECTORY(),"\n"
  PRINT FILE filenam "Diskspace:        ",
                       DRIVESPACE(SUBSTR(DIRECTORY(),1,1)),"\n"
  PRINT FILE filenam "Is Runtime        ",FORMAT("LY",ISRUNTIME()),"\n"
  PRINT FILE filenam "Is Blank Zero     ",FORMAT("LY",ISBLANKZERO()),"\n"
  PRINT FILE filenam "Private Directory:",PRIVDIR(),"\n"
  PRINT FILE filenam "User Name:        ",USERNAME(),"\n"
  PRINT FILE filenam "Script Directory: ",SDIR(),"\n"
  PRINT FILE filenam "Query Order:      ",QUERYORDER(),"\n"
  PRINT FILE filenam "Sort Order:       ",SORTORDER(),"\n"
  PRINT FILE filenam "Version:          ",VERSION(),"\n"
  IF ISASSIGNED(procname) THEN
    PRINT FILE filenam "Cur Proc:         ",procname,"\n"
  ELSE
    PRINT FILE filenam "Cur Proc:         ** Not Set **\n"
  ENDIF
  ;
  ; NOTE: The above is here to save the name of the current PROC being
  ;       executed.  This will only work if procname is set at the beginning
  ;       of every procedure and it is a global variable
  ;
  PRINT FILE filenam "# of images:      ",NIMAGES(),"\n"
  PRINT FILE filenam "Image Type:       ",IMAGETYPE(),"\n"
  IF IMAGETYPE() <> "None" THEN

    PRINT FILE filenam "Current Table:    ",TABLE(),"\n"
    PRINT FILE filenam "Table Shared:     ",FORMAT("LY",ISSHARED(TABLE())),"\n"
    IF IMAGETYPE() = "Display" THEN
      IF ISFORMVIEW() THEN
        PRINT FILE filenam "View Type:        Form\n"
        PRINT FILE filenam "Form #:           ",FORM(),"\n"
        PRINT FILE filenam "MultiTable Form:  ",
                            FORMAT("LY",ISMULTIFORM(TABLE(),FORM())),"\n"
        FORMKEY                             ;  Put into Table View
      ELSE
        PRINT FILE filenam "View Type:        Table\n"
      ENDIF
      PRINT FILE filenam "Current Image #:  ",IMAGENO(),"\n"
      PRINT FILE filenam "Current Field:    ",FIELD(),"\n"
      PRINT FILE filenam "Cur View Rcd #:   ",RECNO(),"\n"
      PRINT FILE filenam "Cur Table Rcd #:  ",[#],"\n"
    ENDIF
    IF NIMAGES() > 0 THEN                   ;  Print name and type of each
                                            ; image on the workspace
      PRINT FILE filenam "Tables placed on the workspace:\n"
      FOR i from 1 to NIMAGES()
        MOVETO i
        PRINT FILE filenam " Table # ",FORMAT("w3",i),":     ",TABLE(),
                           " - ",IMAGETYPE(),"\n"
      ENDFOR
    ENDIF
  ENDIF
  SAVEVARS ALL                              ;  This should be done only for
                                            ; versions 3.0 and above
ENDPROC
