; EmpOnly.sc

PROC FetchEmp()
 PRIVATE employee.data
  SQLFETCH employee.data                    ;  Retrieve employee record
  SQLRELEASE                                ;  Release pending query
  IF retval THEN                            ;  If record retrieved,
    COPYFROMARRAY employee.data             ; place data in Lemp table
    empid = employee.data[2]                ; save Employee Id value
    RETURN True
  ELSE                                      ;  Else no record returned from
    RETURN False                            ; query
  ENDIF
ENDPROC


PROC UpdateEmployee()                       ;  Start a transaction
  SQL
    UPDATE employee
      SET Last_Name      = ~SQLVAL([Last_Name])~,
          First_Name     = ~SQLVAL([First_Name])~,
          Date_hired     = ~SQLVAL([Date_hired])~,
          Birth_date     = ~SQLVAL([Birth_date])~,
          Ssn            = ~SQLVAL([Ssn])~,
          Department     = ~SQLVAL([Department])~,
          Job_code       = ~SQLVAL([Job_code])~,
          Work_phone     = ~SQLVAL([Work_phone])~,
          Salary         = ~SQLVAL([Salary])~,
          Exemptions     = ~SQLVAL([Exemptions])~,
          Address        = ~SQLVAL([Address])~,
          City           = ~SQLVAL([City])~,
          State          = ~SQLVAL([State])~,
          Zip            = ~SQLVAL([Zip])~,
          Home_phone     = ~SQLVAL([Home_phone])~,
          Marital_Status = ~SQLVAL([Marital_status])~,
          Sex            = ~SQLVAL([Sex])~
      WHERE Employee_ID = ~[Employee_ID]~
  ENDSQL
  RETURN retval
ENDPROC


PROC CheckRcdStat()
 PRIVATE retprocval
  IF RECORDSTATUS("Modified") THEN          ;  If the current record has been
    SWITCH                                  ; modified update server record
      CASE tblname = "Lemp"     : retprocval = UpdateEmployee()
      CASE tblname = "Lbene"    : retprocval = UpdateBenefits()
      CASE tblname = "Ldepndts" : retprocval = UpdateDepndnts()
    ENDSWITCH
    RETURN retprocval                       ;  Return the success or failure
  ELSE                                      ; status of the update
    RETURN True
  ENDIF
ENDPROC



PROC EmpOnly()
 PRIVATE tblname, retkey, msg
  COEDIT "lemp"
  PICKFORM 2
  SQLRELEASE                                ; Release any active SQL NOFETCH
  msg    = ""
  SQL NOFETCH                               ; RETRIEVE THE EMPLOYEE DATA
    select * from employee order by employee_id
  ENDSQL
  IF retval = True THEN
    FetchEmp()
    IF retval = False THEN
      MESSAGE "No employee records, modification cancelled!"
      SLEEP 3000
      RETURN
    ENDIF

    SQLSTARTTRANS                           ; Start a transaction on the server

    IF retval = True THEN
      CANVAS ON
      WHILE True
        WAIT RECORD
          prompt "View Employee Information  [F2]-Exit  [Esc]-Cancel",
                 "[PgDn]-Next Record  [PgUp]-Previous Record"
          MESSAGE msg
          UNTIL "F2","PgUp","PgDn","Esc",
                "DOS","DOSBIG","ZOOM","ZOOMNEXT"
        retkey = retval
        msg = ""
        tblname = TABLE()

; *************************************************
; *                                               *
; * Data validation should be done here           *
; *                                               *
; *************************************************

        CheckRcdStat()                      ;  Check to see if the record was
                                            ; was updated, if so, update server
        SWITCH
          CASE retkey = "F2"  :
               CLEAR
               MESSAGE "Saving data, Please wait!"
               CANVAS OFF
               DEL
               DO_IT!

               SQLCOMMIT                    ; Commit the modifications

               QUITLOOP
          CASE retkey = "PgDn" :
               SQL NOFETCH
                 select * from employee  where employee_id > ~empid~
                  order by employee_id
               ENDSQL
               IF retval = True THEN
                 FetchEmp()
               ELSE
                 msg = "Select failed!"
               ENDIF
               LOOP
          CASE retkey = "PgUp" :
               SQL NOFETCH
                 select * from employee  where employee_id < ~empid~
                  order by employee_id desc
               ENDSQL
               IF retval = True THEN
                 FetchEmp()
               ELSE
                 msg = "Select failed!"
               ENDIF
          CASE retkey = "Esc" :
               SHOWMENU
                 "No"  :  "Do Not cancel sesssion, Return to form",
                 "Yes" :  "Cancel ENTIRE session"
               TO cancelchoice
               IF cancelchoice = "Yes" THEN
                 CLEAR
                 MESSAGE "Session cancelled, modifications are being" +
                         " rolled back!"
                 CANVAS OFF

                 SQLROLLBACK           ;  Roll back the transaction

                 DEL                   ; Delete record in holding table
                 DO_IT!
                 QUITLOOP
               ENDIF
               LOOP
        ENDSWITCH
      ENDWHILE
    ELSE
      MESSAGE "Could not start transaction: ",SQLERRORMESSAGE()
      kp = getchar()
    ENDIF
  ELSE
    MESSAGE "Extract failed: ",SQLERRORMESSAGE()
  ENDIF
  CLEARALL
  CANVAS ON
ENDPROC


message "Retrieving data and loading form, Please wait"
CANVAS ON
CANVAS OFF

EmpOnly()
