/* listdb.c

   This code example lists the contents of a table.  The table name can
   be include along with the program name.  If it is not, the program
   prompts for the name of a table.
*/

#include <stdio.h>
#include "pxengine.h"

#define NET_NAME_PATH           "c:\\apps\\paradox3"
#define NET_TYPE                NOTONNET
#define USER_NAME               "demoprog"

#define SUCCESS		        0

#define MAX_FIELDS		255
#define MAX_BUFFER_SIZE	        26
#define MAX_FILENAME_SIZE	40

int main(int, char **);
void Intro();
int Initialize(void);
void OpenTable(char *);
void GetTableStructure(void);
void PrintTable(void);
void PrintTableRecord(int);
void CloseTable(void);
void Terminate(void);

TABLEHANDLE tableHandle;
RECORDHANDLE recHandle;
char fieldNames[MAX_FIELDS][MAX_BUFFER_SIZE];
char fieldTypes[MAX_FIELDS][MAX_BUFFER_SIZE];
int nFields;
RECORDNUMBER nRecs;

int main(int argc, char **argv)
{
    char filename[MAX_FILENAME_SIZE + 1];
    int pxErr=0;

    system("cls");                              /* clear the screen          */
    if (Initialize() == SUCCESS)                /* initialize system         */
        {
        if (argc > 1)                           /* if table name included at */
            OpenTable(argv[1]);                 /* startup open the table    */
        else
        {
            Intro();                            /* display introduction text */
            printf("Enter table name: ");       /* prompt for table name     */
            scanf("%s",filename);
            OpenTable(filename);                /* attemp to open table      */
        }
        GetTableStructure();                    /* determines table structure*/
        PrintTable();                           /* prints records            */
        CloseTable();                           /* closes table              */
        Terminate();                            /* terminates the engine     */
        }
    else
        printf("%s\n", PXErrMsg(pxErr));        /* print error message if    */
                                                /* the Engine could not be   */
                                                /* initialized               */

    return(pxErr);                              /* exit and return value of  */
                                                /* Engine error code         */
}

int Initialize(void)
{
    return(PXNetInit(NET_NAME_PATH, NET_TYPE, USER_NAME));
}

void Intro()
{
    printf("\nThis is a program that reads from a Paradox table,\n"
           "and prints the data to the screen, each field on a \n"
           "separate line.\n\n");
}


void OpenTable(char *tableName)
{
    if(PXTblOpen(tableName, &tableHandle, 0, 0)) 
    {
        printf("Cannot open table %s\n", tableName);
        exit(1);
    }
    PXRecBufOpen(tableHandle, &recHandle);      /* don't forget error chk */
}

void GetTableStructure(void)
{
    int i;

    PXTblNRecs(tableHandle, &nRecs);
    PXRecNFlds(tableHandle, &nFields);
    for(i = 0; i < nFields; i++) 
    {
        PXFldName(tableHandle, (FIELDHANDLE) i + 1,
        MAX_BUFFER_SIZE, fieldNames[i]);
        PXFldType(tableHandle, (FIELDHANDLE) i + 1,
        MAX_BUFFER_SIZE, fieldTypes[i]);
    }
}

void PrintTable(void)
{
    int i;

    for(i = 0; i < nRecs; i++) 
    {
        PXRecGoto(tableHandle, i + 1);
        PXRecGet(tableHandle, recHandle);
        PrintTableRecord(i);
    }
}

void PrintTableRecord(int rcdnum)
{
    int i;
    double dvalue;
    char avalue[BUFSIZ];
    int mo, da, yr;
    long lvalue;
    short svalue;

    printf("%-25s: %d\n", "Record #", rcdnum);
    for(i = 0; i < nFields; i++) 
    {
        switch(fieldTypes[i][0]) 
        {
            case 'N':
            case '$':
                PXGetDoub(recHandle, i + 1, &dvalue);
                printf("%-25s: %g\n", fieldNames[i], dvalue);
                break;
            case 'A':
                PXGetAlpha(recHandle, i + 1, BUFSIZ, avalue);
                printf("%-25s: %s\n", fieldNames[i], avalue);
                break;
            case 'D':
                PXGetDate(recHandle, i + 1, &lvalue);
                PXDateDecode(lvalue, &mo, &da, &yr);
                printf("%-25s: %d/%d/%d\n", fieldNames[i], mo, da, yr);
                break;
            case 'S':
                PXGetShort(recHandle, i + 1, &svalue);
                printf("%-25s: %d\n", fieldNames[i], svalue);
                break;
            default:
                printf("unknown\n");
                break;
        }
    }
    putchar('\n');
}

void CloseTable(void)
{
    PXRecBufClose(recHandle);
    PXTblClose(tableHandle);
}

void Terminate(void)
{
    PXExit();
}

