; Graphs.sc

;  This script contains the procedures for the graph menu selections


?? "."
PROC GraphSalByGndr()
 PRIVATE choice,gtype,oldqorder
  CLEAR
  ExplodeWindow(4,18,10,70,60,"N","Y")
  @ 9,0
  SETMARGIN  12
  STYLE ATTRIBUTE 60
  TEXT

         Select the aggregate type from the above menu
         to create the graph on.
  ENDTEXT
  STYLE
  SHOWMENU
    "Sum"     : "Graph the summation of all employees by gender",
    "Min"     : "Graph the minimum salary of all employees by gender",
    "Max"     : "Graph the maximum salary of all employees by gender",
    "Avg"     : "Graph the average salary of all employees by gender"
  TO choice
  SWITCH
    CASE choice = "Sum"  : gtype = "Calc sum"
    CASE choice = "Min"  : gtype = "Calc min"
    CASE choice = "Max"  : gtype = "Calc min"
    CASE choice = "Avg"  : gtype = "Calc average"
    OTHERWISE            : CLEAR
                           MESSAGE "Graph cancelled"
                           SLEEP 2000
                           CLEARALL
                           RETURN
  ENDSWITCH

  RetrieveMsg("Selecting data")
  CANVAS OFF
  oldqorder = QUERYORDER()
  SETQUERYORDER IMAGEORDER
  Query

   Employee | Department |  Sex   |  Salary  |
            | Check      | Check  |          |


  Endquery
  [Salary] = gtype
  Do_It!
  Enter CrosstabKey
  Menu {Image} {Graph} {Load} SELECT "Gndr"+choice GraphKey ClearAll
  IF oldqorder = "TableOrder" THEN
    SETQUERYORDER TABLEORDER
  ELSE
    SETQUERYORDER IMAGEORDER
  ENDIF
ENDPROC

WRITELIB libname GraphSalByGndr
RELEASE PROCS GraphSalByGndr

?? "."
PROC GraphBudByDept()
  ShowMsg("Summarizing Budget data, Please wait!","OFF","Y",0)
  Query

   Budgets |  Dept  |  Year  | Q1 | Q2 | Q3 |              Q4              |
           | Check  | Check  | _1 | _2 | _3 | _4,calc _1+_2+_3+_4 as Total |

  Endquery

  DO_IT!
  IF ISEMPTY("Answer") THEN
    ShowMsg("No budget data available, Graph cancelled!","OFF","Y",0)
    RETURN
  ENDIF
  ShowMsg("Generating graph, Please wait!","OFF","Y",0)
  TAB CROSSTABKEY
  MENU {Image} {Graph} {Load} {Budcomp}
  GRAPHKEY
ENDPROC

WRITELIB libname GraphBudByDept
RELEASE PROCS GraphBudByDept

?? "."
PROC GraphActByDept()
  ShowMsg("Summarizing Actuals data, Please wait!","OFF","Y",0)
  Query

   Actuals |  Dept  |  Year  | Q1 | Q2 | Q3 |              Q4              |
           | Check  | Check  | _1 | _2 | _3 | _4,calc _1+_2+_3+_4 as Total |

  Endquery

  DO_IT!
  IF ISEMPTY("Answer") THEN
    ShowMsg("No Actuals data available, Graph cancelled!","OFF","Y",0)
    RETURN
  ENDIF
  ShowMsg("Generating graph, Please wait!","OFF","Y",0)
  TAB CROSSTABKEY
  MENU {Image} {Graph} {Load} {Actcomp}
  GRAPHKEY
ENDPROC

WRITELIB libname GraphActByDept
RELEASE PROCS GraphActByDept

?? "."
PROC GraphActToBud()
  CLEARALL
  CLEAR
  @ 5,0 ?? "Enter the year to compare: "
  STYLE ATTRIBUTE 33
  ACCEPT "A2" MIN "90" PICTURE "##" TO sumyr
  CURSOR OFF
  STYLE
  CLEAR
  RetrieveMsg("Extracting records for 19" + sumyr)
  CANVAS OFF
  IF sumyr = "Esc" OR ISBLANK(sumyr) THEN
    ShowMsg("No year entered, query cancelled!","OFF","Y",2000)
    RETURN False
  ENDIF

  ShowMsg("Summarizing Budget and Actuals data, Please wait!","OFF","N",0)
  Query

   Budgets | Dept | Year | Category |                 Q1                 |
           | _aaa | _ccc | _bbb     | _b1,calc _b1+_b2+_b3+_b4 as Budget |

   Budgets | Q2  | Q3  | Q4  |
           | _b2 | _b3 | _b4 |

   Actuals |    Dept     |     Year     | Category |                  Q1                  |
           | Check _aaa! | _ccc!,~sumyr | _bbb!    | _a1, calc _a1+_a2+_a3+_a4 as Actuals |

   Actuals | Q2  | Q3  | Q4  |
           | _a2 | _a3 | _a4 |

  Endquery
  DO_IT!
  CLEARALL
  IF ISEMPTY("Answer") THEN
    ShowMsg("No Budget & Actuals data available, Graph cancelled!","OFF",
            "Y",2000)
    RETURN False
  ENDIF
  Query

   Answer |  Dept  |       Budget       |       Actuals       |
          | Check  | calc sum as Budget | calc sum as Actuals |

  Endquery
  DO_IT!
  TAB TAB                                   ;  Moveto Budget colum
  ShowMsg("Generating graph, Please wait!","OFF","N",0)
  MENU {Image} {Graph} {Load} {Bud2Act}
  GRAPHKEY
ENDPROC

WRITELIB libname GraphActToBud
RELEASE PROCS GraphActToBud

?? "."
PROC GraphDeptBudPercent()
  CLEARALL
  CLEAR
  @ 5,0 ?? "Enter the year to graph: "
  STYLE ATTRIBUTE 33
  ACCEPT "A2" MIN "90" PICTURE "##" TO sumyr
  CURSOR OFF
  STYLE
  CLEAR
  RetrieveMsg("Extracting records for 19" + sumyr)
  CANVAS OFF
  IF sumyr = "Esc" OR ISBLANK(sumyr) THEN
    ShowMsg("No year entered, query cancelled!","OFF","Y",2000)
    RETURN False
  ENDIF

  ShowMsg("Summarizing Budget data, Please wait!","OFF","N",0)
  Query

   Budgets |  Dept  |  Year        | Q1 | Q2 | Q3 |              Q4              |
           | Check  | Check ~sumyr | _1 | _2 | _3 | _4,calc _1+_2+_3+_4 as Total |

  Endquery
  DO_IT!
  IF ISEMPTY("Answer") THEN
    ShowMsg("No Budget data available, Graph cancelled!","OFF","Y",0)
    RETURN
  ENDIF
  ShowMsg("Generating graph, Please wait!","OFF","N",0)
  TAB CROSSTABKEY
  MENU {Image} {Graph} {Load} {Budprcnt}
  SetGraphTitle("Budget Percentage By Department","For Year 19" + sumyr)
  GRAPHKEY
  MENU {Cancel} {Yes}
ENDPROC

WRITELIB libname GraphDeptBudPercent
RELEASE PROCS GraphDeptBudPercent



