; KeyVioln.sc

; If in a multitable form and in master record, cannot use KEYLOOKUP but
; RESYNC key will set ERRORCODE to 53 indicating a duplicate key.
;  If in a detail table, issuing a KEYLOOKUP will set ERRORCODE to 56
; indicating there is no key violations otherwise the errorcode is not set
; indicating a duplicate key exists and KEYLOOKUP is executed again to return
; the data back to the original state.  BUT!!!  Anytime you change any nonkey
; fields in record, KEYLOOKUP returns a 0 and there are two records with the
; same key, one with the data before the changes, and one with the changes.
; Using an array for the before and an array for the after, checking the
; elements of the array for the number of key fields determines if the changes
; were to the key fields or nonkey fields.
;
; NOTE: This procedure needs the array rcd.old to be created and contain
;       the contents of the record before any changes were made.
;
;  Using this method, there is no "temporary" loss of data by copying to an
; array, delete the record, insert, copy from an array.  An UNDO works with
; this process without loss of data.


PROC AnyKeyViol()
 PRIVATE rcd.temp, i
  IF RECORDSTATUS("New") THEN               ;  Test if for new record in table
    LOCKRECORD
    IF RECORDSTATUS("KeyViol")  THEN
      msg = "Record duplicates an existing value, renter"
      COPYTOARRAY rcd.temp
      COPYFROMARRAY rcd.temp
      RETURN True
    ELSE
      RETURN False
    ENDIF
  ELSE
    IF RECORDSTATUS("Modified") THEN
      IF ISFORMVIEW() THEN
        IF ISMULTIFORM(TABLE(),FORM()) THEN
          IF LINKTYPE() = "None" THEN         ;  Must be in master table
            RESYNCKEY
            IF ERRORCODE() = 53 THEN          ;  Duplicate key ?? should other codes be checked
              msg = "Record duplicates an existing value, renter"
              RETURN True
            ELSE
              RETURN False
            ENDIF
          ENDIF
        ENDIF
      ENDIF
;
;  If the following code is executed, must be one of the following:
;     - not in a form
;     - if in a form, it is a single table form
;     - if in a form and it is a multitable form, must be in a detail table
;
      KEYLOOKUP
      IF ERRORCODE() = 56 THEN             ;  No duplicate key found
        RETURN False
      ELSE
        KEYLOOKUP                     ;  Return record to values entered
        COPYTOARRAY rcd.temp
        FOR i FROM 1 to NKEYFIELDS(TABLE())
          IF  rcd.old[1+i] <> rcd.temp[1+i] THEN
            msg = "Record duplicates an existing value, renter"
            RETURN True
          ENDIF
        ENDFOR
        RETURN False
      ENDIF
    ELSE                            ;  The record was not changed
      RETURN False
    ENDIF
  ENDIF
ENDPROC

PROC SaveRcd()
  COPYTOARRAY rcd.old
ENDPROC

