; VldyChks.sc

;  This script contains the procedures to validate data for each table

?? "."
 PROC FldBlank(fldnm,fldtxt)
  PRIVATE fldblnk
 ;
 ;  Procedure to test if the field passed as a parameter is blank. If the field
 ; is blank the procedure returns True, otherwise False is returned.
 ; fldnm   - Field name as defined in the table
 ; fldtxt  - Text to be inserted into the global variable "msg" that is displayed
 ;           to the user if the field is blank
 ; fldblnk - Variable for the logical result of the ISBLANK function

   EXECUTE "fldblnk = ISBLANK(["+fldnm+"])" ;  Create a PAL statement to test
   IF fldblnk THEN                          ; if the field is blank. If it is
     MOVETO FIELD fldnm                     ; empty, move to the field, set
     msg = fldtxt+" must be entered"        ; the msg variable and return
     RETURN True
   ELSE
     RETURN False
   ENDIF
 ENDPROC

WRITELIB libname FldBlank
RELEASE PROCS FldBlank

?? "."
PROC ActualsVldtyChk()
  IF FldBlank("Year","Year") THEN                ; Required Year
    RETURN False
  ENDIF
  IF FldBlank("Category","Category") THEN        ; Required Category
    RETURN False
  ENDIF
  RETURN True
ENDPROC

WRITELIB libname ActualsVldtyChk
RELEASE PROCS ActualsVldtyChk


?? "."
PROC BudgetsVldtyChk()
  IF FldBlank("Year","Year") THEN                ; Required Year
    RETURN False
  ENDIF
  IF FldBlank("Category","Category") THEN        ; Required Category
    RETURN False
  ENDIF
  RETURN True
ENDPROC

WRITELIB libname BudgetsVldtyChk
RELEASE PROCS BudgetsVldtyChk


?? "."
PROC DeptVldtyChk()
  IF FldBlank("Department","Department") THEN    ; Required Department
    RETURN False
  ENDIF
  IF FldBlank("Manager","Manager") THEN          ; Required Manager
    RETURN False
  ENDIF
  RETURN True
ENDPROC

WRITELIB libname DeptVldtyChk
RELEASE PROCS DeptVldtyChk

?? "."
PROC CategoryVldtyChk()
  IF FldBlank("Category","Category") THEN        ; Required Category
    RETURN False
  ENDIF
  RETURN True
ENDPROC

WRITELIB libname CategoryVldtyChk
RELEASE PROCS CategoryVldtyChk


?? "."
PROC JobcdVldtyChk()
  IF FldBlank("Job Code","Job Code") THEN        ; Required Job Code
    RETURN False
  ENDIF
  IF FldBlank("Job Description","Description") THEN   ; Required Description
    RETURN False
  ENDIF
  RETURN True
ENDPROC

WRITELIB libname JobcdVldtyChk
RELEASE PROCS JobcdVldtyChk

?? "."
PROC CrsectgyVldtyChk()
  IF FldBlank("Course Category","Course Category") THEN     ; Required Category
    RETURN False
  ENDIF
  RETURN True
ENDPROC

WRITELIB libname CrsectgyVldtyChk
RELEASE PROCS CrsectgyVldtyChk

?? "."
PROC CrsedescVldtyChk()
  IF FldBlank("Course Number","Course Number") THEN      ; Required Number
    RETURN False
  ENDIF
  IF FldBlank("Course Title","Course Title") THEN        ; Required Title
    RETURN False
  ENDIF
  IF FldBlank("Course Length","Course Length") THEN      ; Required Length
    RETURN False
  ENDIF
  IF FldBlank("Course Category","Course Category") THEN  ; Required Category
    RETURN False
  ENDIF
  RETURN True
ENDPROC

WRITELIB libname CrsedescVldtyChk
RELEASE PROCS CrsedescVldtyChk


?? "."
PROC EmployeeVldtyChk()
  IF FldBlank("Last Name","Last Name") THEN          ; Required Last Name
    RETURN False
  ENDIF
  IF FldBlank("First Name","First Name") THEN        ; Required First Name
    RETURN False
  ENDIF
  IF FldBlank("SSN","SSN") THEN                      ; Required SSN
    RETURN False
  ENDIF
  IF FldBlank("Birth Date","Birth Date") THEN        ; Required Birth Date
    RETURN False
  ENDIF
  IF FldBlank("Department","Department") THEN        ; Required Department
    RETURN False
  ENDIF
  IF FldBlank("Job Code","Job Code") THEN            ; Required Job Code
    RETURN False
  ENDIF
  IF FldBlank("Salary","Salary") THEN                ; Required Salary
    RETURN False
  ENDIF
  IF FldBlank("Work Phone","Work Phone") THEN        ; Required Home Phone
    RETURN False
  ENDIF
  IF ISBLANK([Date Hired]) THEN                      ; Default Hire Date
    [Date Hired] = TODAY()
  ENDIF
  IF ISBLANK([Exemptions]) THEN                      ; Default Exemptions
    [Exemptions] = 0
  ENDIF
  IF [Date Hired] < [Birth Date] + (16 * 365) THEN   ;  Check if Date Hired is
                                                     ; 16 years after Birth Date
    msg = "Birth Date and Hire Date must be 16 years apart"
    MOVETO [Date Hired]
    RETURN False
  ENDIF
  RETURN True
ENDPROC

WRITELIB libname EmployeeVldtyChk
RELEASE PROCS EmployeeVldtyChk


?? "."
PROC BenefitsVldtyChk()
  IF ISBLANK([Insurance Type]) THEN                  ; Default Insurance Type
    [Insurance Type] = "Aetna"
  ENDIF
  IF ISBLANK([Life Insurance]) THEN                  ; Default Life Insurance
    [Life Insurance] = 0
  ENDIF
  IF ISBLANK([Short Term Disab]) THEN                ; Default Short Term Disab
    [Short Term Disab] = "N"
  ENDIF
  IF ISBLANK([Long Term Disab]) THEN                 ; Default Long Term Disab
    [Long Term Disab] = "N"
  ENDIF
  IF ISBLANK([US Saving Bond]) THEN                  ; Default US Saving Bond
    [US Saving Bond] = 0
  ENDIF
  RETURN True
ENDPROC

WRITELIB libname BenefitsVldtyChk
RELEASE PROCS BenefitsVldtyChk


?? "."
PROC DepndntsVldtyChk()
  IF FldBlank("Dependents SSN","Dependents SSN") THEN; Required Dependents SSN
    RETURN False
  ENDIF
  IF FldBlank("Last Name","Last Name") THEN          ; Required Last Name
    RETURN False
  ENDIF
  IF FldBlank("First Name","First Name") THEN        ; Required First Name
    RETURN False
  ENDIF
  RETURN True
ENDPROC

WRITELIB libname DepndntsVldtyChk
RELEASE PROCS DepndntsVldtyChk

?? "."
PROC EductionVldtyChk()
  IF FldBlank("Year","Year") THEN            ; Required Category
    RETURN False
  ENDIF
  IF FldBlank("School","School") THEN        ; Required Category
    RETURN False
  ENDIF
  IF FldBlank("Degree","Degree") THEN        ; Required Category
    RETURN False
  ENDIF
  RETURN True
ENDPROC

WRITELIB libname EductionVldtyChk
RELEASE PROCS EductionVldtyChk



?? "."
PROC TrainingVldtyChk()
  IF FldBlank("Course Number","Course Number") THEN  ; Required Course Number
    RETURN False
  ENDIF
  IF FldBlank("Date Attended","Date Attended") THEN  ; Required Date Attended
    RETURN False
  ENDIF
  RETURN True
ENDPROC

WRITELIB libname TrainingVldtyChk
RELEASE PROCS TrainingVldtyChk


?? "."
PROC EmpEnterVldyChk(tblname)
 PRIVATE retprocval

  SWITCH
    CASE tblname = "Entry" :                  ; Employee table
         retprocval = EmployeeVldtyChk()
         RETURN retprocval
    CASE tblname = "Entry1" :                 ; Benefits table
         retprocval = BenefitsVldtyChk()
         RETURN retprocval
    CASE tblname = "Entry2"  :                ; Depndnts table
         retprocval = DepndntsVldtyChk()
         RETURN retprocval
    OTHERWISE:
         msg = "Table not found, call programmer to fix"
         RETURN False
  ENDSWITCH
ENDPROC

WRITELIB libname EmpEnterVldyChk
RELEASE PROCS EmpEnterVldyChk

?? "."
PROC ValidityChecks(tblname)
 PRIVATE retprocval

  SWITCH
    CASE tblname = "Employee" :             ; Employee table
         retprocval = EmployeeVldtyChk()
         RETURN retprocval
    CASE tblname = "Benefits" :             ; Benefits table
         retprocval = BenefitsVldtyChk()
         RETURN retprocval
    CASE tblname = "Depndnts"  :            ; Depndnts table
         retprocval = DepndntsVldtyChk()
         RETURN retprocval
    CASE tblname = "Eduction"  :            ; Eduction table
         retprocval = EductionVldtyChk()
         RETURN retprocval
    CASE tblname = "Training"  :            ; Training table
         retprocval = TrainingVldtyChk()
         RETURN retprocval
    CASE tblname = "Budgets"  :             ; Budgets table
         retprocval = BudgetsVldtyChk()
         RETURN retprocval
    CASE tblname = "Actuals"  :             ; Actuals table
         retprocval = ActualsVldtyChk()
         RETURN retprocval
    OTHERWISE:
         msg = "Table not found, call programmer to fix"
         RETURN False
  ENDSWITCH
ENDPROC

WRITELIB libname ValidityChecks
RELEASE PROCS ValidityChecks

